escape

Function escape 

pub fn escape(s: &str) -> String
Escape all special glob characters in the given string.

The returned string, when used as a glob pattern, will match the input string literally.