GlobMap

Struct GlobMap 

pub struct GlobMap<T> { /* private fields */ }
A map from glob patterns to values.

GlobMap<T> pairs each glob pattern with an associated value of type T. Lookups return the value associated with the first (lowest-index) matching pattern.

Internally uses the same optimized strategy-based dispatch as GlobSet (extension hash, literal, prefix, suffix, Aho-Corasick pre-filter).

Example

use glob_set::{Glob, GlobMapBuilder};

let mut builder = GlobMapBuilder::new();
builder.insert(Glob::new("*.rs").unwrap(), "rust");
builder.insert(Glob::new("*.toml").unwrap(), "toml");
let map = builder.build().unwrap();

assert_eq!(map.get("foo.rs"), Some(&"rust"));
assert_eq!(map.get("Cargo.toml"), Some(&"toml"));
assert_eq!(map.get("foo.js"), None);

Implementations

Source

impl<T> GlobMap<T>

pub fn get(&self, path: impl AsRef<str>) -> Option<&T>

Return the value associated with the first matching pattern, or None.

pub fn get_candidate(&self, candidate: &Candidate<'_>) -> Option<&T>

Return the value associated with the first matching pattern for a candidate, or None.

pub fn get_matches(&self, path: impl AsRef<str>) -> Vec<&T>

Return references to all values whose patterns match the given path.

Values are returned in match order (same order as GlobSet::matches).

pub fn get_matches_candidate(&self, candidate: &Candidate<'_>) -> Vec<&T>

Return references to all values whose patterns match the given candidate.

pub fn is_match(&self, path: impl AsRef<str>) -> bool

Test whether any pattern matches the given path.

pub fn len(&self) -> usize

Return the number of patterns in this map.

pub fn is_empty(&self) -> bool

Return whether this map is empty.