TinyGlobSet

Struct TinyGlobSet 

pub struct TinyGlobSet { /* private fields */ }
A lightweight glob set that trades query speed for fast construction.

See the module docs for guidance on when to choose this over GlobSet.

Implementations

Source

impl TinyGlobSet

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn is_match(&self, path: impl AsRef<str>) -> bool

pub fn is_match_candidate(&self, candidate: &Candidate<'_>) -> bool

pub fn matches(&self, path: impl AsRef<str>) -> Vec<usize>

pub fn matches_into(&self, path: impl AsRef<str>, into: &mut Vec<usize>)

pub fn matches_candidate(&self, candidate: &Candidate<'_>) -> Vec<usize>

pub fn matches_candidate_into( &self, candidate: &Candidate<'_>, into: &mut Vec<usize>, )